"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const css_1 = require("@emotion/css");
const compass_components_1 = require("@mongodb-js/compass-components");
const form_field_container_1 = __importDefault(require("../../form-field-container"));
const url_options_1 = require("../../../utils/url-options");
const modalContainerStyles = (0, css_1.css)({
    padding: 0,
    'button[aria-label="Close modal"]': {
        position: 'absolute',
    },
});
const modalContentStyles = (0, css_1.css)({
    padding: compass_components_1.spacing[5],
});
const modalFooterStyles = (0, css_1.css)({
    boxShadow: 'none',
    border: 'none',
    borderTop: `1px solid ${compass_components_1.uiColors.gray.light2}`,
});
function UrlOptionsModal({ onClose, selectedOption, onUpdateOption, }) {
    const [errorMessage, setErrorMessage] = react_1.default.useState('');
    const [option, setOption] = react_1.default.useState(selectedOption !== null && selectedOption !== void 0 ? selectedOption : { key: '', value: '' });
    const handleKeyPress = (event) => {
        if (event.key === 'Enter') {
            event.preventDefault();
            addUrlOption();
        }
    };
    const addUrlOption = () => {
        setErrorMessage('');
        if (!option.key) {
            return setErrorMessage('Please select an options key.');
        }
        onUpdateOption(option);
    };
    return (react_1.default.createElement(compass_components_1.Modal, { contentClassName: modalContainerStyles, open: true, setOpen: onClose, "data-testid": "uri-options-modal" },
        react_1.default.createElement("div", { className: modalContentStyles },
            react_1.default.createElement(compass_components_1.H3, null, "Add custom url option"),
            react_1.default.createElement(form_field_container_1.default, null,
                react_1.default.createElement(compass_components_1.Select, { "data-testid": "uri-options-key-field", label: "Key", placeholder: "Select key", name: "key", onChange: (key) => {
                        setOption({
                            key: key,
                            value: option.value,
                        });
                    }, allowDeselect: false, value: option.key }, url_options_1.editableUrlOptions.map(({ title, values }) => (react_1.default.createElement(compass_components_1.OptionGroup, { key: title, label: title }, values.map((value) => (react_1.default.createElement(compass_components_1.Option, { key: value, value: value }, value)))))))),
            react_1.default.createElement(form_field_container_1.default, null,
                react_1.default.createElement(compass_components_1.TextInput, { onChange: ({ target: { value }, }) => {
                        setOption({
                            key: option.key,
                            value,
                        });
                    }, name: 'value', "data-testid": "uri-options-value-field", label: 'Value', type: 'text', placeholder: 'Value', value: option.value, onKeyDown: handleKeyPress }))),
        react_1.default.createElement(compass_components_1.FormFooter, { className: modalFooterStyles, errorMessage: errorMessage, primaryButton: react_1.default.createElement(compass_components_1.Button, { "data-testid": "uri-options-save-button", variant: 'primary', onClick: () => addUrlOption() }, "Save"), onCancel: () => onClose(false) })));
}
exports.default = UrlOptionsModal;
//# sourceMappingURL=url-options-modal.js.map