"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hidePasswordInConnectionString = void 0;
const css_1 = require("@emotion/css");
const react_1 = __importStar(require("react"));
const compass_components_1 = require("@mongodb-js/compass-components");
const confirm_edit_connection_string_1 = __importDefault(require("./confirm-edit-connection-string"));
const mongodb_connection_string_url_1 = __importDefault(require("mongodb-connection-string-url"));
const uriLabelStyles = css_1.css({
    padding: 0,
    margin: 0,
    flexGrow: 1,
});
const infoButtonStyles = css_1.css({
    verticalAlign: 'middle',
    marginTop: -compass_components_1.spacing[1],
});
const textAreaContainerStyle = css_1.css({
    position: 'relative',
});
const connectionStringStyles = css_1.css({
    textarea: {
        minHeight: compass_components_1.spacing[7],
        resize: 'vertical',
    },
});
const editToggleStyles = css_1.css({
    height: 14,
    width: 26,
    margin: compass_components_1.spacing[1],
    marginRight: 0,
});
const editToggleLabelStyles = css_1.css({
    '&:hover': {
        cursor: 'pointer',
    },
});
const textAreaLabelContainerStyles = css_1.css({
    marginTop: compass_components_1.spacing[3],
    display: 'flex',
    flexDirection: 'row',
});
const connectionStringInputId = 'connectionString';
function reducer(state, action) {
    switch (action.type) {
        case 'enable-editing-connection-string':
            return {
                ...state,
                showConfirmEditConnectionStringPrompt: false,
                enableEditingConnectionString: true,
            };
        case 'show-edit-connection-string-confirmation':
            return {
                ...state,
                showConfirmEditConnectionStringPrompt: true,
            };
        case 'hide-connection-string':
            return {
                ...state,
                showConfirmEditConnectionStringPrompt: false,
                enableEditingConnectionString: false,
            };
        case 'hide-edit-connection-string-confirmation':
            return {
                ...state,
                showConfirmEditConnectionStringPrompt: false,
            };
        default:
            return state;
    }
}
function hidePasswordInConnectionString(connectionString) {
    try {
        const passwordHiddenConnectionString = new mongodb_connection_string_url_1.default(connectionString);
        if (passwordHiddenConnectionString.password) {
            passwordHiddenConnectionString.password = '*****';
        }
        if (passwordHiddenConnectionString.searchParams.get('AWS_SESSION_TOKEN')) {
            passwordHiddenConnectionString.searchParams.set('AWS_SESSION_TOKEN', '*****');
        }
        return passwordHiddenConnectionString.toString();
    }
    catch (e) {
        return connectionString;
    }
}
exports.hidePasswordInConnectionString = hidePasswordInConnectionString;
function ConnectStringInput({ connectionString, setConnectionString, }) {
    const [{ enableEditingConnectionString, showConfirmEditConnectionStringPrompt }, dispatch,] = react_1.useReducer(reducer, {
        enableEditingConnectionString: !connectionString,
        showConfirmEditConnectionStringPrompt: false,
    });
    const textAreaEl = react_1.useRef(null);
    const displayedConnectionString = enableEditingConnectionString
        ? connectionString
        : hidePasswordInConnectionString(connectionString);
    return (react_1.default.createElement(react_1.Fragment, null,
        react_1.default.createElement("div", { className: textAreaLabelContainerStyles },
            react_1.default.createElement(compass_components_1.Label, { className: uriLabelStyles, htmlFor: connectionStringInputId },
                "Connection String",
                react_1.default.createElement(compass_components_1.IconButton, { className: infoButtonStyles, "aria-label": "Connection String Documentation", "data-testid": "connectionStringDocsButton", href: "https://docs.mongodb.com/manual/reference/connection-string/", target: "_blank" },
                    react_1.default.createElement(compass_components_1.Icon, { glyph: "InfoWithCircle", size: "small" }))),
            react_1.default.createElement("label", { className: editToggleLabelStyles, id: "edit-connection-string-label", htmlFor: "toggle-edit-connection-string" }, "Edit Connection String"),
            react_1.default.createElement(compass_components_1.Toggle, { className: editToggleStyles, id: "toggle-edit-connection-string", "aria-labelledby": "edit-connection-string-label", size: "xsmall", checked: enableEditingConnectionString, onClick: () => {
                    if (enableEditingConnectionString) {
                        dispatch({
                            type: 'hide-connection-string',
                        });
                        return;
                    }
                    dispatch({
                        type: 'show-edit-connection-string-confirmation',
                    });
                } })),
        react_1.default.createElement("div", { className: textAreaContainerStyle },
            react_1.default.createElement(compass_components_1.TextArea, { onChange: (event) => {
                    setConnectionString(event.target.value);
                }, value: displayedConnectionString, className: connectionStringStyles, disabled: !enableEditingConnectionString, id: connectionStringInputId, ref: textAreaEl, "aria-labelledby": "Connection String", placeholder: "e.g mongodb+srv://username:password@cluster0-jtpxd.mongodb.net/admin" }),
            react_1.default.createElement(confirm_edit_connection_string_1.default, { open: showConfirmEditConnectionStringPrompt, onCancel: () => dispatch({
                    type: 'hide-edit-connection-string-confirmation',
                }), onConfirm: () => dispatch({
                    type: 'enable-editing-connection-string',
                }) }))));
}
exports.default = ConnectStringInput;
//# sourceMappingURL=connection-string-input.js.map