import ConnectionStringUrl from 'mongodb-connection-string-url';
import { ConnectionInfo, ConnectionOptions } from 'mongodb-data-service';
import type { MongoClientOptions } from 'mongodb';
import { ConnectionFormWarning } from '../utils/connect-form-warnings';
import { ConnectionFormError } from '../utils/connect-form-errors';
import { UpdateConnectionOptions } from '../utils/connection-options-handler';
import { TLS_OPTIONS } from '../constants/ssl-tls-options';
export interface ConnectFormState {
    connectionStringInvalidError: string | null;
    connectionOptions: ConnectionOptions;
    connectionStringUrl: ConnectionStringUrl;
    errors: ConnectionFormError[];
    warnings: ConnectionFormWarning[];
}
interface UpdateHostAction {
    type: 'update-host';
    hostIndex: number;
    newHostValue: string;
}
interface UpdateTlsOptionAction {
    type: 'update-tls-option';
    tlsOption: TLS_OPTIONS;
}
declare type ConnectionFormFieldActions = {
    type: 'add-new-host';
    hostIndexToAddAfter: number;
} | {
    type: 'remove-host';
    hostIndexToRemove: number;
} | UpdateHostAction | {
    type: 'update-direct-connection';
    isDirectConnection: boolean;
} | {
    type: 'update-connection-schema';
    isSrv: boolean;
} | UpdateConnectionOptions | UpdateTlsOptionAction | {
    type: 'update-search-param';
    currentKey: keyof MongoClientOptions;
    newKey?: keyof MongoClientOptions;
    value?: unknown;
} | {
    type: 'delete-search-param';
    key: keyof MongoClientOptions;
} | {
    type: 'update-connection-path';
    value: string;
};
export declare type UpdateConnectionFormField = (action: ConnectionFormFieldActions) => void;
export declare function handleConnectionFormFieldUpdate({ action, connectionStringUrl, connectionOptions, initialErrors, }: {
    action: ConnectionFormFieldActions;
    connectionStringUrl: ConnectionStringUrl;
    connectionOptions: ConnectionOptions;
    initialErrors: ConnectionFormError[];
}): {
    connectionStringUrl: ConnectionStringUrl;
    connectionOptions: ConnectionOptions;
    errors: ConnectionFormError[];
};
export declare function useConnectForm(initialConnectionInfo: ConnectionInfo): [
    ConnectFormState,
    {
        setConnectionStringError: (errorMessage: string | null) => void;
        setConnectionStringUrl: (connectionStringUrl: ConnectionStringUrl) => void;
        updateConnectionFormField: UpdateConnectionFormField;
        hideError: (index: number) => void;
        hideWarning: (index: number) => void;
    }
];
export {};
